def leer_pdf():
    try:
        text = 'Hola'
        print(text)
    except:
        pass